==> django-cte-trees-python3-1.0b2.tar.gz: django-cte-trees-python3-1.0b2/setup.py <==
# -*- coding: utf-8 -*-
#
# This document is free and open-source software, subject to the OSI-approved
# BSD license below.
#
# Copyright (c) 2011 - 2013 Alexis Petrounias <www.petrounias.org>,
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# * Redistributions of source code must retain the above copyright notice, this
# list of conditions and the following disclaimer.
#
# * Redistributions in binary form must reproduce the above copyright notice,
# this list of conditions and the following disclaimer in the documentation
# and/or other materials provided with the distribution.
#
# * Neither the name of the author nor the names of its contributors may be used
# to endorse or promote products derived from this software without specific
# prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
# SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
# CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
# OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

""" Setuptools for Django CTE Trees.
"""

__status__ = "beta"
__version__ = "1.0.0b2"
__maintainer__ = (u"David Hoffman", )

# Setup tools
from setuptools import setup, find_packages

 
setup(
    name = 'django-cte-trees-python3',
    version = ":versiontools:cte_tree:VERSION",
    packages = find_packages(),
    maintainer = 'David Hoffman',
    maintainer_email = 'david.hoffman@stjoseph.com',
    keywords = 'django, postgresql, cte, trees, sql',
    license = 'BSD',
    description = 'Django Adjacency-List trees using PostgreSQL Common Table Expressions (CTE).',
    url = 'https://github.com/stjosephcontent/django-cte-trees',
    download_url = "https://github.com/stjosephcontent/django-cte-trees/archive/master.zip",
    classifiers = [
        'Development Status :: 3 - Alpha',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
    setup_requires = [ 'versiontools >= 1.3.1', ],
    tests_require = [ 'Django >= 1.2', ],
    zip_safe = True)

==> django-cte-trees-python3-1.0.2.tar.gz: django-cte-trees-python3-1.0.2/setup.py <==
# -*- coding: utf-8 -*-
#
# This document is free and open-source software, subject to the OSI-approved
# BSD license below.
#
# Copyright (c) 2011 - 2013 Alexis Petrounias <www.petrounias.org>,
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# * Redistributions of source code must retain the above copyright notice, this
# list of conditions and the following disclaimer.
#
# * Redistributions in binary form must reproduce the above copyright notice,
# this list of conditions and the following disclaimer in the documentation
# and/or other materials provided with the distribution.
#
# * Neither the name of the author nor the names of its contributors may be used
# to endorse or promote products derived from this software without specific
# prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
# SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
# CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
# OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

""" Setuptools for Django CTE Trees.
"""

__status__ = "alpha"
__version__ = "1.0.2"
__maintainer__ = (u"David Hoffman", )

# Setup tools
from setuptools import setup, find_packages

 
setup(
    name = 'django-cte-trees-python3',
    version = ":versiontools:cte_tree:VERSION",
    packages = find_packages(),
    maintainer = 'David Hoffman',
    maintainer_email = 'david.hoffman@stjoseph.com',
    keywords = 'django, postgresql, cte, trees, sql',
    license = 'BSD',
    description = 'Django Adjacency-List trees using PostgreSQL Common Table Expressions (CTE).',
    url = 'https://github.com/stjosephcontent/django-cte-trees',
    download_url = "https://github.com/stjosephcontent/django-cte-trees/archive/master.zip",
    classifiers = [
        'Development Status :: 3 - Alpha',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
    setup_requires = [ 'versiontools >= 1.3.1', ],
    tests_require = [ 'Django >= 1.2', ],
    zip_safe = True)
